@@ -4,8 +4,8 @@ use warnings;
 use utf8;
 
 package Neo4j::Driver::ResultColumns;
-# ABSTRACT: structure definition of Cypher result values
-$Neo4j::Driver::ResultColumns::VERSION = '0.08'; # TRIAL
+# ABSTRACT: Structure definition of Cypher result values
+$Neo4j::Driver::ResultColumns::VERSION = '0.19'; # TRIAL
 
 use Carp qw(croak);
 
@@ -18,7 +18,6 @@ sub new {
 	my $column_keys = {};
 	for (my $f = scalar(@$columns) - 1; $f >= 0; $f--) {
 		$column_keys->{$columns->[$f]} = $f;
-		$column_keys->{$f} = $f;
 	}
 	
 	return bless $column_keys, $class;
@@ -28,15 +27,26 @@ sub new {
 sub key {
 	my ($self, $key) = @_;
 	
+	# returns the index [!] of the field specified by the given key
 	return $self->{$key};
 }
 
 
+sub list {
+	my ($self) = @_;
+	warnings::warnif deprecated => "Neo4j::Driver::Record->{column_keys} is deprecated";
+	
+	# returns the unordered list of keys
+	# (prior to version 0.1701, the list was returned in the original order)
+	return keys %$self;
+}
+
+
 sub add {
 	my ($self, $column) = @_;
 	
 	my $index = $self->count;
-	$self->{$column} = $self->{$index} = $index;
+	$self->{$column} = $index;
 	return $index;
 }
 
@@ -44,8 +54,7 @@ sub add {
 sub count {
 	my ($self) = @_;
 	
-	my $column_count = (scalar keys %$self) >> 1;  # each column has two hash entries (numeric and by name)
-	return $column_count;
+	return scalar $self->list;
 }
 
 
@@ -59,11 +68,16 @@ __END__
 
 =head1 NAME
 
-Neo4j::Driver::ResultColumns - structure definition of Cypher result values
+Neo4j::Driver::ResultColumns - Structure definition of Cypher result values
 
 =head1 VERSION
 
-version 0.08
+version 0.19
+
+=head1 DESCRIPTION
+
+The L<Neo4j::Driver::ResultColumns> package is not part of the
+public L<Neo4j::Driver> API.
 
 =head1 AUTHOR
 
@@ -71,7 +85,7 @@ Arne Johannessen <ajnn@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016-2018 by Arne Johannessen.
+This software is Copyright (c) 2016-2021 by Arne Johannessen.
 
 This is free software, licensed under:
 
